summaryrefslogtreecommitdiff
path: root/setup.py
diff options
context:
space:
mode:
authorCole Robinson <crobinso@redhat.com>2020-01-26 18:29:39 -0500
committerCole Robinson <crobinso@redhat.com>2020-01-27 06:57:37 -0500
commite784376699b1c7c5477f033b16323bca42d7158f (patch)
tree56803398bd5054085538bc4b4d4bb7ce2c5f770b /setup.py
parent78c8aef75e92a34ecef95669af49c1bdc0cbe06f (diff)
downloadvirt-manager-e784376699b1c7c5477f033b16323bca42d7158f.tar.gz
tests: Rename all test files to have test_ prefix
This will help for a possible future conversion to pytest Signed-off-by: Cole Robinson <crobinso@redhat.com>
Diffstat (limited to 'setup.py')
-rwxr-xr-xsetup.py12
1 files changed, 6 insertions, 6 deletions
diff --git a/setup.py b/setup.py
index cc776598..7db0439f 100755
--- a/setup.py
+++ b/setup.py
@@ -516,18 +516,18 @@ class TestCommand(TestBaseCommand):
'''
Finds all the tests modules in tests/, and runs them.
'''
- excludes = ["dist.py", "test_urls.py", "test_inject.py"]
+ excludes = ["test_dist.py", "test_urls.py", "test_inject.py"]
testfiles = self._find_tests_in_dir("tests", excludes)
# Put clitest at the end, since it takes the longest
for f in testfiles[:]:
- if "clitest" in f:
+ if "test_cli" in f:
testfiles.remove(f)
testfiles.append(f)
# Always want to put checkprops at the end to get accurate results
for f in testfiles[:]:
- if "checkprops" in f:
+ if "test_checkprops" in f:
testfiles.remove(f)
if not self.testfile:
testfiles.append(f)
@@ -593,7 +593,7 @@ class TestDist(TestBaseCommand):
description = "Tests to run before cutting a release"
def run(self):
- self._testfiles = ["tests.dist"]
+ self._testfiles = ["tests.test_dist"]
TestBaseCommand.run(self)
@@ -516,18 +516,18 @@ class TestCommand(TestBaseCommand):
testfiles = self._find_tests_in_dir("tests", excludes)
- # Put clitest at the end, since it takes the longest
+ # Put test_cli at the end, since it takes the longest
for f in testfiles[:]:
@@ -516,18 +516,18 @@ class TestCommand(TestBaseCommand):
testfiles.remove(f)
testfiles.append(f)
- # Always want to put checkprops at the end to get accurate results
+ # Always want to put test_checkprops at the end to get accurate results
for f in testfiles[:]: